==> credentials-2.1.5-sources.jar: com/cloudbees/plugins/credentials/cli/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.plugins.credentials.cli;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code DeleteCredentialsCommand.ShortDescription}: {@code Delete a
     * Credential}.
     * 
     * @return
     *     {@code Delete a Credential}
     */
    public static String DeleteCredentialsCommand_ShortDescription() {
        return holder.format("DeleteCredentialsCommand.ShortDescription");
    }

    /**
     * Key {@code DeleteCredentialsCommand.ShortDescription}: {@code Delete a
     * Credential}.
     * 
     * @return
     *     {@code Delete a Credential}
     */
    public static Localizable _DeleteCredentialsCommand_ShortDescription() {
        return new Localizable(holder, "DeleteCredentialsCommand.ShortDescription");
    }

    /**
     * Key {@code UpdateCredentialsByXmlCommand.ShortDescription}: {@code
     * Update Credentials by XML}.
     * 
     * @return
     *     {@code Update Credentials by XML}
     */
    public static String UpdateCredentialsByXmlCommand_ShortDescription() {
        return holder.format("UpdateCredentialsByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code UpdateCredentialsByXmlCommand.ShortDescription}: {@code
     * Update Credentials by XML}.
     * 
     * @return
     *     {@code Update Credentials by XML}
     */
    public static Localizable _UpdateCredentialsByXmlCommand_ShortDescription() {
        return new Localizable(holder, "UpdateCredentialsByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsProvidersCommand.ShortDescription}: {@code
     * List Credentials Providers}.
     * 
     * @return
     *     {@code List Credentials Providers}
     */
    public static String ListCredentialsProvidersCommand_ShortDescription() {
        return holder.format("ListCredentialsProvidersCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsProvidersCommand.ShortDescription}: {@code
     * List Credentials Providers}.
     * 
     * @return
     *     {@code List Credentials Providers}
     */
    public static Localizable _ListCredentialsProvidersCommand_ShortDescription() {
        return new Localizable(holder, "ListCredentialsProvidersCommand.ShortDescription");
    }

    /**
     * Key {@code CreateCredentialsDomainByXmlCommand.ShortDescription}:
     * {@code Create Credentials Domain by XML}.
     * 
     * @return
     *     {@code Create Credentials Domain by XML}
     */
    public static String CreateCredentialsDomainByXmlCommand_ShortDescription() {
        return holder.format("CreateCredentialsDomainByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code CreateCredentialsDomainByXmlCommand.ShortDescription}:
     * {@code Create Credentials Domain by XML}.
     * 
     * @return
     *     {@code Create Credentials Domain by XML}
     */
    public static Localizable _CreateCredentialsDomainByXmlCommand_ShortDescription() {
        return new Localizable(holder, "CreateCredentialsDomainByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code DeleteCredentialsDomainCommand.ShortDescription}: {@code
     * Delete a Credentials Domain}.
     * 
     * @return
     *     {@code Delete a Credentials Domain}
     */
    public static String DeleteCredentialsDomainCommand_ShortDescription() {
        return holder.format("DeleteCredentialsDomainCommand.ShortDescription");
    }

    /**
     * Key {@code DeleteCredentialsDomainCommand.ShortDescription}: {@code
     * Delete a Credentials Domain}.
     * 
     * @return
     *     {@code Delete a Credentials Domain}
     */
    public static Localizable _DeleteCredentialsDomainCommand_ShortDescription() {
        return new Localizable(holder, "DeleteCredentialsDomainCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsCommand.ShortDescription}: {@code Lists the
     * Credentials in a specific Store}.
     * 
     * @return
     *     {@code Lists the Credentials in a specific Store}
     */
    public static String ListCredentialsCommand_ShortDescription() {
        return holder.format("ListCredentialsCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsCommand.ShortDescription}: {@code Lists the
     * Credentials in a specific Store}.
     * 
     * @return
     *     {@code Lists the Credentials in a specific Store}
     */
    public static Localizable _ListCredentialsCommand_ShortDescription() {
        return new Localizable(holder, "ListCredentialsCommand.ShortDescription");
    }

    /**
     * Key {@code UpdateCredentialsDomainByXmlCommand.ShortDescription}:
     * {@code Update Credentials Domain by XML}.
     * 
     * @return
     *     {@code Update Credentials Domain by XML}
     */
    public static String UpdateCredentialsDomainByXmlCommand_ShortDescription() {
        return holder.format("UpdateCredentialsDomainByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code UpdateCredentialsDomainByXmlCommand.ShortDescription}:
     * {@code Update Credentials Domain by XML}.
     * 
     * @return
     *     {@code Update Credentials Domain by XML}
     */
    public static Localizable _UpdateCredentialsDomainByXmlCommand_ShortDescription() {
        return new Localizable(holder, "UpdateCredentialsDomainByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code CreateCredentialsByXmlCommand.ShortDescription}: {@code
     * Create Credential by XML}.
     * 
     * @return
     *     {@code Create Credential by XML}
     */
    public static String CreateCredentialsByXmlCommand_ShortDescription() {
        return holder.format("CreateCredentialsByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code CreateCredentialsByXmlCommand.ShortDescription}: {@code
     * Create Credential by XML}.
     * 
     * @return
     *     {@code Create Credential by XML}
     */
    public static Localizable _CreateCredentialsByXmlCommand_ShortDescription() {
        return new Localizable(holder, "CreateCredentialsByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code GetCredentialsDomainAsXmlCommand.ShortDescription}: {@code
     * Get a Credentials Domain as XML}.
     * 
     * @return
     *     {@code Get a Credentials Domain as XML}
     */
    public static String GetCredentialsDomainAsXmlCommand_ShortDescription() {
        return holder.format("GetCredentialsDomainAsXmlCommand.ShortDescription");
    }

    /**
     * Key {@code GetCredentialsDomainAsXmlCommand.ShortDescription}: {@code
     * Get a Credentials Domain as XML}.
     * 
     * @return
     *     {@code Get a Credentials Domain as XML}
     */
    public static Localizable _GetCredentialsDomainAsXmlCommand_ShortDescription() {
        return new Localizable(holder, "GetCredentialsDomainAsXmlCommand.ShortDescription");
    }

    /**
     * Key {@code GetCredentialsAsXmlCommand.ShortDescription}: {@code Get a
     * Credentials as XML (secrets redacted)}.
     * 
     * @return
     *     {@code Get a Credentials as XML (secrets redacted)}
     */
    public static String GetCredentialsAsXmlCommand_ShortDescription() {
        return holder.format("GetCredentialsAsXmlCommand.ShortDescription");
    }

    /**
     * Key {@code GetCredentialsAsXmlCommand.ShortDescription}: {@code Get a
     * Credentials as XML (secrets redacted)}.
     * 
     * @return
     *     {@code Get a Credentials as XML (secrets redacted)}
     */
    public static Localizable _GetCredentialsAsXmlCommand_ShortDescription() {
        return new Localizable(holder, "GetCredentialsAsXmlCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsContextResolversCommand.ShortDescription}:
     * {@code List Credentials Context Resolvers}.
     * 
     * @return
     *     {@code List Credentials Context Resolvers}
     */
    public static String ListCredentialsContextResolversCommand_ShortDescription() {
        return holder.format("ListCredentialsContextResolversCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsContextResolversCommand.ShortDescription}:
     * {@code List Credentials Context Resolvers}.
     * 
     * @return
     *     {@code List Credentials Context Resolvers}
     */
    public static Localizable _ListCredentialsContextResolversCommand_ShortDescription() {
        return new Localizable(holder, "ListCredentialsContextResolversCommand.ShortDescription");
    }

}

==> credentials-2.3.19-sources.jar: com/cloudbees/plugins/credentials/cli/Messages.java <==
// CHECKSTYLE:OFF

package com.cloudbees.plugins.credentials.cli;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code DeleteCredentialsCommand.ShortDescription}: {@code Delete a
     * Credential}.
     * 
     * @return
     *     {@code Delete a Credential}
     */
    public static String DeleteCredentialsCommand_ShortDescription() {
        return holder.format("DeleteCredentialsCommand.ShortDescription");
    }

    /**
     * Key {@code DeleteCredentialsCommand.ShortDescription}: {@code Delete a
     * Credential}.
     * 
     * @return
     *     {@code Delete a Credential}
     */
    public static Localizable _DeleteCredentialsCommand_ShortDescription() {
        return new Localizable(holder, "DeleteCredentialsCommand.ShortDescription");
    }

    /**
     * Key {@code UpdateCredentialsByXmlCommand.ShortDescription}: {@code
     * Update Credentials by XML}.
     * 
     * @return
     *     {@code Update Credentials by XML}
     */
    public static String UpdateCredentialsByXmlCommand_ShortDescription() {
        return holder.format("UpdateCredentialsByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code UpdateCredentialsByXmlCommand.ShortDescription}: {@code
     * Update Credentials by XML}.
     * 
     * @return
     *     {@code Update Credentials by XML}
     */
    public static Localizable _UpdateCredentialsByXmlCommand_ShortDescription() {
        return new Localizable(holder, "UpdateCredentialsByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsProvidersCommand.ShortDescription}: {@code
     * List Credentials Providers}.
     * 
     * @return
     *     {@code List Credentials Providers}
     */
    public static String ListCredentialsProvidersCommand_ShortDescription() {
        return holder.format("ListCredentialsProvidersCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsProvidersCommand.ShortDescription}: {@code
     * List Credentials Providers}.
     * 
     * @return
     *     {@code List Credentials Providers}
     */
    public static Localizable _ListCredentialsProvidersCommand_ShortDescription() {
        return new Localizable(holder, "ListCredentialsProvidersCommand.ShortDescription");
    }

    /**
     * Key {@code CreateCredentialsDomainByXmlCommand.ShortDescription}:
     * {@code Create Credentials Domain by XML}.
     * 
     * @return
     *     {@code Create Credentials Domain by XML}
     */
    public static String CreateCredentialsDomainByXmlCommand_ShortDescription() {
        return holder.format("CreateCredentialsDomainByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code CreateCredentialsDomainByXmlCommand.ShortDescription}:
     * {@code Create Credentials Domain by XML}.
     * 
     * @return
     *     {@code Create Credentials Domain by XML}
     */
    public static Localizable _CreateCredentialsDomainByXmlCommand_ShortDescription() {
        return new Localizable(holder, "CreateCredentialsDomainByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code DeleteCredentialsDomainCommand.ShortDescription}: {@code
     * Delete a Credentials Domain}.
     * 
     * @return
     *     {@code Delete a Credentials Domain}
     */
    public static String DeleteCredentialsDomainCommand_ShortDescription() {
        return holder.format("DeleteCredentialsDomainCommand.ShortDescription");
    }

    /**
     * Key {@code DeleteCredentialsDomainCommand.ShortDescription}: {@code
     * Delete a Credentials Domain}.
     * 
     * @return
     *     {@code Delete a Credentials Domain}
     */
    public static Localizable _DeleteCredentialsDomainCommand_ShortDescription() {
        return new Localizable(holder, "DeleteCredentialsDomainCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsCommand.ShortDescription}: {@code Lists the
     * Credentials in a specific Store}.
     * 
     * @return
     *     {@code Lists the Credentials in a specific Store}
     */
    public static String ListCredentialsCommand_ShortDescription() {
        return holder.format("ListCredentialsCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsCommand.ShortDescription}: {@code Lists the
     * Credentials in a specific Store}.
     * 
     * @return
     *     {@code Lists the Credentials in a specific Store}
     */
    public static Localizable _ListCredentialsCommand_ShortDescription() {
        return new Localizable(holder, "ListCredentialsCommand.ShortDescription");
    }

    /**
     * Key {@code UpdateCredentialsDomainByXmlCommand.ShortDescription}:
     * {@code Update Credentials Domain by XML}.
     * 
     * @return
     *     {@code Update Credentials Domain by XML}
     */
    public static String UpdateCredentialsDomainByXmlCommand_ShortDescription() {
        return holder.format("UpdateCredentialsDomainByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code UpdateCredentialsDomainByXmlCommand.ShortDescription}:
     * {@code Update Credentials Domain by XML}.
     * 
     * @return
     *     {@code Update Credentials Domain by XML}
     */
    public static Localizable _UpdateCredentialsDomainByXmlCommand_ShortDescription() {
        return new Localizable(holder, "UpdateCredentialsDomainByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code CreateCredentialsByXmlCommand.ShortDescription}: {@code
     * Create Credential by XML}.
     * 
     * @return
     *     {@code Create Credential by XML}
     */
    public static String CreateCredentialsByXmlCommand_ShortDescription() {
        return holder.format("CreateCredentialsByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code CreateCredentialsByXmlCommand.ShortDescription}: {@code
     * Create Credential by XML}.
     * 
     * @return
     *     {@code Create Credential by XML}
     */
    public static Localizable _CreateCredentialsByXmlCommand_ShortDescription() {
        return new Localizable(holder, "CreateCredentialsByXmlCommand.ShortDescription");
    }

    /**
     * Key {@code GetCredentialsDomainAsXmlCommand.ShortDescription}: {@code
     * Get a Credentials Domain as XML}.
     * 
     * @return
     *     {@code Get a Credentials Domain as XML}
     */
    public static String GetCredentialsDomainAsXmlCommand_ShortDescription() {
        return holder.format("GetCredentialsDomainAsXmlCommand.ShortDescription");
    }

    /**
     * Key {@code GetCredentialsDomainAsXmlCommand.ShortDescription}: {@code
     * Get a Credentials Domain as XML}.
     * 
     * @return
     *     {@code Get a Credentials Domain as XML}
     */
    public static Localizable _GetCredentialsDomainAsXmlCommand_ShortDescription() {
        return new Localizable(holder, "GetCredentialsDomainAsXmlCommand.ShortDescription");
    }

    /**
     * Key {@code GetCredentialsAsXmlCommand.ShortDescription}: {@code Get a
     * Credentials as XML (secrets redacted)}.
     * 
     * @return
     *     {@code Get a Credentials as XML (secrets redacted)}
     */
    public static String GetCredentialsAsXmlCommand_ShortDescription() {
        return holder.format("GetCredentialsAsXmlCommand.ShortDescription");
    }

    /**
     * Key {@code GetCredentialsAsXmlCommand.ShortDescription}: {@code Get a
     * Credentials as XML (secrets redacted)}.
     * 
     * @return
     *     {@code Get a Credentials as XML (secrets redacted)}
     */
    public static Localizable _GetCredentialsAsXmlCommand_ShortDescription() {
        return new Localizable(holder, "GetCredentialsAsXmlCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsContextResolversCommand.ShortDescription}:
     * {@code List Credentials Context Resolvers}.
     * 
     * @return
     *     {@code List Credentials Context Resolvers}
     */
    public static String ListCredentialsContextResolversCommand_ShortDescription() {
        return holder.format("ListCredentialsContextResolversCommand.ShortDescription");
    }

    /**
     * Key {@code ListCredentialsContextResolversCommand.ShortDescription}:
     * {@code List Credentials Context Resolvers}.
     * 
     * @return
     *     {@code List Credentials Context Resolvers}
     */
    public static Localizable _ListCredentialsContextResolversCommand_ShortDescription() {
        return new Localizable(holder, "ListCredentialsContextResolversCommand.ShortDescription");
    }

}
